@@ -67,19 +67,19 @@ use FindBin qw($Bin);
 use File::Find;
 use Config;
 
-use vars qw( $VERSION $PERL $COVERAGE_THRESHOLD $COVER $UNTAINT_PATTERN $PERL_PATTERN $CAN_USE_WARNINGS $TEST_SYNTAX $TEST_STRICT $TEST_WARNINGS $TEST_SKIP $DEVEL_COVER_OPTIONS $DEVEL_COVER_DB );
-$VERSION = '0.22';
-$PERL    = $^X || 'perl';
-$COVERAGE_THRESHOLD = 50; # 50%
-$UNTAINT_PATTERN    = qr|^(.*)$|;
-$PERL_PATTERN       = qr/^#!.*perl/;
-$CAN_USE_WARNINGS   = ($] >= 5.006);
-$TEST_SYNTAX   = 1;  # Check compile
-$TEST_STRICT   = 1;  # Check use strict;
-$TEST_WARNINGS = 0;  # Check use warnings;
-$TEST_SKIP     = []; # List of files to skip check
-$DEVEL_COVER_OPTIONS = '+ignore,".Test.Strict\b"';
-$DEVEL_COVER_DB      = 'cover_db';
+our $COVER;
+our $VERSION = '0.25';
+our $PERL    = $^X || 'perl';
+our $COVERAGE_THRESHOLD = 50; # 50%
+our $UNTAINT_PATTERN    = qr|^(.*)$|;
+our $PERL_PATTERN       = qr/^#!.*perl/;
+our $CAN_USE_WARNINGS   = ($] >= 5.006);
+our $TEST_SYNTAX   = 1;  # Check compile
+our $TEST_STRICT   = 1;  # Check use strict;
+our $TEST_WARNINGS = 0;  # Check use warnings;
+our $TEST_SKIP     = []; # List of files to skip check
+our $DEVEL_COVER_OPTIONS = '+ignore,".Test.Strict\b"';
+our $DEVEL_COVER_DB      = 'cover_db';
 my $IS_WINDOWS = $^O =~ /MSwin/i;
 
 my $Test  = Test::Builder->new;
@@ -127,6 +127,7 @@ sub _all_files {
     return if ($File::Find::dir =~ m![\\/]?blib[\\/]libdoc$!); # Filter out pod doc in dist
     return if ($File::Find::dir =~ m![\\/]?blib[\\/]man\d$!); # Filter out pod doc in dist
     return unless (-f $File::Find::name && -r _);
+    return if ($File::Find::name =~ m!\.#.+?[\d\.]+$!);         # Filter out CVS backup files (.#file.revision)
     push @found, File::Spec->canonpath( File::Spec->no_upwards( $File::Find::name ) );
   };
   my $find_arg = {
@@ -227,83 +228,94 @@ sub _strict_ok {
         return 1;
       }
     }
+    if (/\buse\s+(5.01\d+)/ and $1 >= 5.012) {
+      return 1;
+    }
   }
   return;
 }
 
 =head2 modules_enabling_strict
 
-Experimental. Returning a list of modules and pragmata that enable strict
+Experimental. Returning a list of modules and pragmata that enable strict.
+To modify this list, change C<@Test::Strict::MODULES_ENABLING_STRICT>.
 
-List taken from https://metacpan.org/source/DAXIM/Module-CPANTS-Analyse-0.86/lib/Module/CPANTS/Kwalitee/Uses.pm
+List taken from https://metacpan.org/pod/Module::CPANTS::Kwalitee::Uses v95
 
 =cut
 
-sub modules_enabling_strict {
- return qw(
-   strict
-   Any::Moose
-   Class::Spiffy
-   Coat
-   common::sense
-   Dancer
-   Mo
-   Modern::Perl
-   Mojo::Base
-   Moo
-   Moose
-   Moose::Exporter
-   Moose::Role
-   MooseX::Declare
-   MooseX::Types
-   Mouse
-   Mouse::Role
-   perl5
-   perl5i::1
-   perl5i::2
-   perl5i::latest
-   Spiffy
-   strictures
- );
-}
+our @MODULES_ENABLING_STRICT = qw(
+  strict
+  Any::Moose
+  Catmandu::Sane
+  Class::Spiffy
+  Coat
+  common::sense
+  Dancer
+  Mo
+  Modern::Perl
+  Mojo::Base
+  Moo
+  Moo::Role
+  Moose
+  Moose::Exporter
+  Moose::Role
+  MooseX::Declare
+  MooseX::Role::Parameterized
+  MooseX::Types
+  Mouse
+  Mouse::Role
+  perl5
+  perl5i::1
+  perl5i::2
+  perl5i::latest
+  Role::Tiny
+  Spiffy
+  strictures
+);
+
+sub modules_enabling_strict { return @MODULES_ENABLING_STRICT }
 
 =head2 modules_enabling_warnings
 
-Experimental. Returning a list of modules and pragmata that enable strict
+Experimental. Returning a list of modules and pragmata that enable warnings
+To modify this list, change C<@Test::Strict::MODULES_ENABLING_WARNINGS>.
 
-List taken from https://metacpan.org/source/DAXIM/Module-CPANTS-Analyse-0.86/lib/Module/CPANTS/Kwalitee/Uses.pm
+List taken from https://metacpan.org/pod/Module::CPANTS::Kwalitee::Uses v95
 
 =cut
 
-sub modules_enabling_warnings {
- return qw(
-    warnings
-    Any::Moose
-    Class::Spiffy
-    Coat
-    common::sense
-    Dancer
-    Mo
-    Modern::Perl
-    Mojo::Base
-    Moo
-    Moose
-    Moose::Exporter
-    Moose::Role
-    MooseX::Declare
-    MooseX::Types
-    Mouse
-    Mouse::Role
-    perl5
-    perl5i::1
-    perl5i::2
-    perl5i::latest
-    Spiffy
-    strictures
- );
-}
-
+our @MODULES_ENABLING_WARNINGS = qw(
+  warnings
+  Any::Moose
+  Catmandu::Sane
+  Class::Spiffy
+  Coat
+  common::sense
+  Dancer
+  Mo
+  Modern::Perl
+  Mojo::Base
+  Moo
+  Moo::Role
+  Moose
+  Moose::Exporter
+  Moose::Role
+  MooseX::Declare
+  MooseX::Role::Parameterized
+  MooseX::Types
+  Mouse
+  Mouse::Role
+  perl5
+  perl5i::1
+  perl5i::2
+  perl5i::latest
+  Role::Tiny
+  Spiffy
+  strictures
+);
 
+sub modules_enabling_warnings { return @MODULES_ENABLING_WARNINGS }
 
 =head2 warnings_ok( $file [, $text] )
 
